From mboxrd@z Thu Jan 1 00:00:00 1970 Return-Path: Received: (majordomo@vger.kernel.org) by vger.kernel.org via listexpand id S1753664AbdEIPWb (ORCPT ); Tue, 9 May 2017 11:22:31 -0400 Received: from mail-wr0-f195.google.com ([209.85.128.195]:35740 "EHLO mail-wr0-f195.google.com" rhost-flags-OK-OK-OK-OK) by vger.kernel.org with ESMTP id S1753336AbdEIPW2 (ORCPT ); Tue, 9 May 2017 11:22:28 -0400 Subject: Re: [PATCH v2 0/3] nVMX: Emulated Page Modification Logging for Nested Virtualization To: Bandan Das , kvm@vger.kernel.org Cc: linux-kernel@vger.kernel.org References: <20170505192515.27833-1-bsd@redhat.com> From: Paolo Bonzini Message-ID: Date: Tue, 9 May 2017 17:22:22 +0200 User-Agent: Mozilla/5.0 (X11; Linux x86_64; rv:52.0) Gecko/20100101 Thunderbird/52.0 MIME-Version: 1.0 In-Reply-To: <20170505192515.27833-1-bsd@redhat.com> Content-Type: text/plain; charset=utf-8 Content-Language: en-US Content-Transfer-Encoding: 8bit Sender: linux-kernel-owner@vger.kernel.org List-ID: X-Mailing-List: linux-kernel@vger.kernel.org On 05/05/2017 21:25, Bandan Das wrote: > v2: > 2/3: Clear out all bits except bit 12 > 3/3: Slightly modify an existing comment, honor L0's > PML setting when clearing it for L1 > > v1: > http://www.spinics.net/lists/kvm/msg149247.html > > These patches implement PML on top of EPT A/D emulation > (ae1e2d1082ae). > > When dirty bit is being set, we write the gpa to the > buffer provided by L1. If the index overflows, we just > change the exit reason before running L1. I tested this with api/dirty-log-perf, and nested PML is more than 3 times faster than pml=0. I want to do a few more tests because I don't see any PML full exits in the L1 trace, but it seems to be a nice improvement! Paolo > Bandan Das (3): > kvm: x86: Add a hook for arch specific dirty logging emulation > nVMX: Implement emulated Page Modification Logging > nVMX: Advertise PML to L1 hypervisor > > arch/x86/include/asm/kvm_host.h | 2 + > arch/x86/kvm/mmu.c | 15 +++++++ > arch/x86/kvm/mmu.h | 1 + > arch/x86/kvm/paging_tmpl.h | 4 ++ > arch/x86/kvm/vmx.c | 97 ++++++++++++++++++++++++++++++++++++++--- > 5 files changed, 112 insertions(+), 7 deletions(-) >